#
# spec file for package dbh
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           dbh
%define lname	lib%{name}2
Summary:        Disk-Based Hash Library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Version:        5.0.22
Release:        2.2
Url:            https://www.gnu.org/software/libdbh/

Source:         https://downloads.sf.net/dbh/%{lname}-%{version}.tar.gz
Patch0:         dbh-bigendian.patch
# PATCH-FIX-OPENSUSE -- bmwiedemann - make builds reproducible
Patch1:         reproducible.patch
BuildRequires:  fdupes
BuildRequires:  gtk-doc
BuildRequires:  libtool
BuildRequires:  pkg-config

%description
Disk-based hashes is a method to create multidimensional binary trees
on disk. This library permits the extension of the database concept to
a plethora of electronic data, such as graphic information. With the
multidimensional binary tree, it is possible to mathematically prove
that access time to any particular record is minimized (using the
concept of critical points from calculus), which provides the means to
construct optimized databases for particular applications.

%package -n %lname
Summary:        Disk-Based Hash Library
Group:          System/Libraries
Obsoletes:      dbh < %version-%release
Provides:       dbh = %version-%release

%description -n %lname
Disk-based hashes is a method to create multidimensional binary trees
on disk. This library permits the extension of the database concept to
a plethora of electronic data, such as graphic information. With the
multidimensional binary tree, it is possible to mathematically prove
that access time to any particular record is minimized (using the
concept of critical points from calculus), which provides the means to
construct optimized databases for particular applications.

%package devel
Summary:        Development files for the Disk-Based Hash Library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
Disk-based hashes is a method to create multidimensional binary trees
on disk. This library permits the extension of the database concept to
a plethora of electronic data, such as graphic information. With the
multidimensional binary tree, it is possible to mathematically prove
that access time to any particular record is minimized (using the
concept of critical points from calculus), which provides the means to
construct optimized databases for particular applications.

%prep
%autosetup -p1 -n %{lname}-%{version}

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
rm -f %{buildroot}/%{_libdir}/*.la
rm -rf %{buildroot}/%{_datadir}/dbh
# create symlinks for man pages
%fdupes -s %buildroot/%_mandir
%fdupes -s examples

%check
make check

%files -n %lname
%_libdir/lib*.so.*

%files devel
%doc AUTHORS ChangeLog README examples/*.c examples/Makefile*
%license COPYING
%{_datadir}/gtk-doc
%{_includedir}/*
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*.3.*

%post -n %lname -p /sbin/ldconfig

%postun -n %lname -p /sbin/ldconfig

%changelog
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Fri Jun 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 5.0.22
  * Added function  dbh_find_top(), variant for dbh_find()
  * Added PKGBUILD for easy cross compilation from ArchLinux
  * Fixes for mingw-w64 cross compilation on ArchLinux box.
  * Fixes dbh_set_data() not updating data when growing record size
  * Fixes strncmp() should be replaced by memcmp()
  * Fixes Excessive syscalls with tiny read() calls
  * This version reduces calls to read() from 3 to 1 when
    maximum record size is less than 64KB, falling back to
    5.0.21 behavior when dealing with records with greater size.
- Remove buildfix.patch, was fixed Upstream
* Tue Jan 17 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
  Add buildfix.patch to allow build on kernel versions containing fc
* Mon Mar 21 2016 dvaleev@suse.com
- Fix bigendian builds (dbh-bigendian.patch)
* Mon Nov 16 2015 p.drouand@gmail.com
- Update to version 5.0.19
  * Build fixes.
  * Remove INVALIDATE flag from msync (not allowed with ASYNC in FreeBSD)
- Changes from version 5.0.17
  * Minor bugfixes detected with Coverity analysis
  * Include performance test code and graphs in tarball
* Fri Jan  9 2015 jengelh@inai.de
- Specify upstream source URL and update package groups.
  Drop --with-pic which is implicit anyway.
* Sun Jan  4 2015 p.drouand@gmail.com
- Update to version 5.0.16
  + fix a incorrect seleccion of temporary workdir location
- Add dependencies to gtk-doc, libtool and pkg-config; new upstream
  requirements
- Add fdupes build require
- Symlink redundant files with %%fdupes -s
- Bump SO name to 2
- doc/*.html is not available anymore; do no perform %%doc for this
  directory
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
- Implement shlib policy
* Wed Jan 28 2009 crrodriguez@suse.de
- remove static libraries and "la" files
- -fPIC --> --with-pic
* Mon Feb 19 2007 lmichnovic@suse.cz
- compiling with fPIC, fixes build on S390
* Fri Jun 30 2006 pnemec@suse.cz
- update to 4.5.0
  inspite of progresive version change it is just bugfix
  release
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Sep 14 2005 cthiel@suse.de
- specfile cleanup
* Wed May 18 2005 cthiel@suse.de
- update to 1.0.24
* Mon Apr 11 2005 cthiel@suse.de
- update to 1.0.22
* Wed May 12 2004 ltinkl@suse.cz
- fix packaging the *.pc files
* Wed May 12 2004 ltinkl@suse.cz
- initial version
